==> haskell-apply-refact-0.14.0.0-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-apply-refact.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 apply-refact
version:              0.14.0.0
visibility:           public
id:                   apply-refact-0.14.0.0-Kqwi59yEDyFFFhq6KxHfnk
key:                  apply-refact-0.14.0.0-Kqwi59yEDyFFFhq6KxHfnk
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
homepage:             https://github.com/mpickering/apply-refact
synopsis:             Perform refactorings specified by the refact library.
description:
    Perform refactorings specified by the refact library. It is primarily used with HLint'\''s --refactor flag.

category:             Development
abi:                  4dcaac29a2cfa0ff226c4a31c3e3c173
exposed:              True
exposed-modules:
    Refact.Apply Refact.Compat Refact.Fixity Refact.Internal
    Refact.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/apply-refact-0.14.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/apply-refact-0.14.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/apply-refact-0.14.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-apply-refact
hs-libraries:         HSapply-refact-0.14.0.0-Kqwi59yEDyFFFhq6KxHfnk
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    extra-1.7.16-FVFc4gt4avs4Z4Fwytd6v6
    filemanip-0.3.6.3-ANqGDzaSV4G7mOoTW92ati ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-exactprint-1.6.1-HID3MHkBx8fBdLLS900rUG
    process-1.6.18.0 refact-0.3.0.2-KPJC6T8FqM8EMkV2k8FDeA
    syb-0.7.3-B3ujAx0b01UAjArJbq6cUd transformers-0.5.6.2
    uniplate-1.6.13-CJ0oCvoijnU13momfUMYNw
    unix-compat-0.7.4.1-4uh2N5X0qi8J6n5m3thcXg

haddock-interfaces:
    /usr/share/doc/haskell-apply-refact/html/apply-refact.haddock

haddock-html:         /usr/share/doc/haskell-apply-refact/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-apply-refact-0.14.0.0-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-apply-refact.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 apply-refact
version:              0.14.0.0
visibility:           public
id:                   apply-refact-0.14.0.0-Fi8pcc2mHQUGAHX8htwBNf
key:                  apply-refact-0.14.0.0-Fi8pcc2mHQUGAHX8htwBNf
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
homepage:             https://github.com/mpickering/apply-refact
synopsis:             Perform refactorings specified by the refact library.
description:
    Perform refactorings specified by the refact library. It is primarily used with HLint'\''s --refactor flag.

category:             Development
abi:                  449cec84876d5d36a39e814732cb2060
exposed:              True
exposed-modules:
    Refact.Apply Refact.Compat Refact.Fixity Refact.Internal
    Refact.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/apply-refact-0.14.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/apply-refact-0.14.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/apply-refact-0.14.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-apply-refact
hs-libraries:         HSapply-refact-0.14.0.0-Fi8pcc2mHQUGAHX8htwBNf
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    extra-1.7.16-5tezMKqv9GA6gNR4q67AdR
    filemanip-0.3.6.3-L7TmArhMxom8tkoAY0Vcwz ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-exactprint-1.6.1-ABHKZrApRFu6wz789oIolb
    process-1.6.18.0 refact-0.3.0.2-KPJC6T8FqM8EMkV2k8FDeA
    syb-0.7.3-B3ujAx0b01UAjArJbq6cUd transformers-0.5.6.2
    uniplate-1.6.13-DF7uAUfFe5vBT2gaRnKTZa
    unix-compat-0.7.4.1-7wl3VN2bkjVLyACPiFBxN

haddock-interfaces:
    /usr/share/doc/haskell-apply-refact/html/apply-refact.haddock

haddock-html:         /usr/share/doc/haskell-apply-refact/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
